#
# spec file for package commandergenius
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           commandergenius
Version:        2.4.2
Release:        bp153.1.19
Summary:        An open clone of the Commander Keen engines
License:        GPL-2.0-only
Group:          Amusements/Games/Action/Arcade
URL:            http://clonekeenplus.sf.net/
#Git-Clone:     https://gitlab.com/Dringgstein/Commander-Genius.git
Source:         https://gitlab.com/Dringgstein/Commander-Genius/-/archive/v%version/Commander-Genius-v%version.tar.bz2
BuildRequires:  boost-devel
BuildRequires:  cmake >= 2.8
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL2_image) >= 2.0.0
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(zlib)

%description
Commander Genius is a software piece that interprets the Commander
Keen Vorticon (1-3) and Galaxy (3½-6) series.

It has 4-player cooperative mode and six difficulty modes.

%prep
%setup -q -n Commander-Genius-v%version

%build
%cmake \
  -DCMAKE_INSTALL_PREFIX="%_prefix" \
  -DAPPDIR="%_bindir"
%make_jobs

%install
%cmake_install
%fdupes %buildroot%_datadir

%files
%license COPYRIGHT
%_bindir/CGeniusExe
%_datadir/applications/cgenius.desktop
%_datadir/icons/hicolor/
%_datadir/games/%name/

%changelog
* Sat May 23 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.4.2
  * SDL_Cursor now should work as intended
  * Finally added some scroll arrows to list views
  * More loading feedback especially for galaxy audio
  * Adding some emscripten code so GsKit is compatible with WASM
  * Some resolution and rendering improvements
  * Keen dreams freezes less especially when using cheat codes
  * Fixed broken Messie to Player interaction
  * Added Quicksave (F6) and Quickload (F9) so dying is less
    tedious
  * Added Integer scaling of video resoltion
  * Added 640x360 game resolution which scales nice to 1920x1080
* Thu Apr  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.4.1
  * Added an achievement system for keen4se.
* Sun Mar 15 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.4.0
  * Fixed problem with some dialogs in vorticon keen engine
  * Improved the code for save game menus
  * Added option where you can choose whether you type your save
    game or a timestamp is automatically entered instead
  * Disabled button cannot be triggered anymore as it should be
* Sat Dec 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.3.9
  * Virtualpad improvements
  * Android improvements
  * Settings improvements for horizontal border size
  * Crash fixes, bug fixes
* Fri Nov  1 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.3.6
  - Scrollbar improvements
  - Crash fixes, bug fixes
  - Search path issues fixed
  - New font added for better scalibility
  - Updated GsKit, many code cleanups in the library
  - Settings fixups
  - Modern setting makes the dithering effect a bit smoother when
    Galaxy is shown
  - Brought back the info menu for help and ordering info
  - More log messages for better feedback
- Use %%cmake macros
- Run spec-cleaner
* Tue Aug  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.2.3
  * Tweaked Game menu design
  * Optimized compilation process
  * Reduce some compiler warnings
  * Overall code modernization
  * AI improvements
  * Collision improvements with switches
- Take the source from the upstream authors gitlab instance.
  The github mirror wasn't up to date.
* Fri Jul 27 2018 jengelh@inai.de
- Update to new upstream release 2.2.2
  * Player selection in Keen 4 Plus. Play as Lindsey, Council or
    Kyle.
  * Different character in Multiplayer mode.
  * Added support for Mod, Midi and FLAC.
  * Sprite selection screen when Single player mode (Galaxy).
* Sat Mar 17 2018 jengelh@inai.de
- Update to new upstream release 2.0.7
  * Integration of the KeenDreams GPLed engine
  * Many AI fixes in Keen 4, 5 and 6
  * Platform sprite corrections in Keen 5
  * Many collision fixes
  * Smoother scrolling with vsync
- Remove commandergenius-nocurrentdate.diff (no longer needed)
* Sun May  3 2015 dap.darkness@gmail.com
- Updated to 1.8.1.1 to resolve openSUSE:Factory build failures:
  * Dosbox fusion;
  * A lot of dosbox fixes;
  * Better mouse controls;
  * New submenu for mods;
  * More fixes and AI improvements;
  * More native resolutions if higher modes are used,
    especially in the launcher;
  * Some improved physics;
  * Shorter game names;
  * Last window size is now saved automatically;
  * Heavy engine independent code cleanups which will make CG more
    flexible for new game engines besides Commander Keen;
  * New GsLib will take more work at low level functions and will
    as wrapper for SDL and GUI elements;
  * Multiple selection problem should be fixed now;
  * Even more smooth effects readded;
  * New pump event concept will solve a lot of deadlocks we
    previously had on the android versions;
  * Added Scrollbar for a bigger list of games;
  * Wormmoutch bites again;
  * More effects readded;
  * Many bug fixes especially Keen 1,2 and 4.
- Switched from tarball to _service.
- Added commandergenius-nocurrentdate.diff vs. useless rebuilds.
- General spec clean up.
* Thu Jan 30 2014 jengelh@inai.de
- Initial package (version 1.6.5.5) for build.opensuse.org
